==> endemic-0.1.0.tar.gz: endemic-0.1.0/src/endemic/logging/fluentd/logger.py <==
import logging
from fluent import handler
from ..interface import LoggerInterface

custom_format = {
    'host': '%(hostname)s',
    'type': '%(levelname)s',
    'stack_trace': '%(exc_text)s',
    'time': '%(created)s',
    'stack_info': '%(stack_info)s',
}


class LoggerFluentd(LoggerInterface):

    # threads - number of pool threads
    def __init__(
            self,
            instance: str,
            log_name: str,
            logger_tag: str = 'fluentd',
            level: str = LoggerInterface.DEBUG,
            host: str = '',
            port: int = 0
    ):
        super().__init__()
        self.__log = logging

        self.__instance_name = instance

        self.__fluentd_host = host
        self.__fluentd_port = port

        self.__logging_level = level
        self.__logging_logger = logger_tag
        self.__logging_name = log_name

        self.__min_info = []
        self.__min_warning = []

        self.__link = ''
        self.__where_call = None
        self.__who_call = None

        self.__setting()

    def __setting(self):
        """
        Setting logger and console output
        """
        logging.basicConfig(level=self.__logging_level,
                            format='%(asctime)s %(levelname)-8s %(message)s',
                            datefmt='%d/%m %H:%M')

        if self.__min_info:
            for i in self.__min_info:
                logging.getLogger(i).setLevel(logging.INFO)

        if self.__min_warning:
            for i in self.__min_warning:
                logging.getLogger(i).setLevel(logging.WARNING)

        if self.__fluentd_port and self.__fluentd_host:
            h = handler.FluentHandler(self.__logging_name, host=self.__fluentd_host, port=self.__fluentd_port)
        else:
            h = handler.FluentHandler(self.__logging_name)

        formatter = handler.FluentRecordFormatter(custom_format)
        h.setFormatter(formatter)

        self.__log = logging.getLogger(self.__logging_logger)

        if self.__fluentd_port and self.__fluentd_host:
            self.__log.addHandler(h)

    def debug(self, message, tag=None, class_name: str = None, variables: dict = None, method_name: str = None):
        self.__log.debug({**{self.MESSAGE: message, self.TAG: tag}, **self.custom(variables, class_name, method_name)})

    def info(self, message, tag=None, class_name: str = None, variables: dict = None, method_name: str = None):
        self.__log.info({**{self.MESSAGE: message, self.TAG: tag}, **self.custom(variables, class_name, method_name)})

    def warning(self, message, tag=None, class_name: str = None, variables: dict = None, method_name: str = None):
        self.__log.warning(
            {**{self.MESSAGE: message, self.TAG: tag}, **self.custom(variables, class_name, method_name)})

    def error(self, message, tag=None, class_name: str = None, variables: dict = None, method_name: str = None):
        self.__log.error({**{self.MESSAGE: message, self.TAG: tag}, **self.custom(variables, class_name, method_name)})

    def exception(self, message=None, tag=None, class_name: str = None, variables: dict = None,
                  method_name: str = None):
        self.__log.exception(
            **{self.MESSAGE: 'Exception', self.TAG: tag}, **self.custom(variables, class_name, method_name))

    def critical(self, message, tag=None, class_name: str = None, variables: dict = None, method_name: str = None):
        self.__log.critical({self.MESSAGE: message, self.TAG: tag}, **self.custom(variables, class_name, method_name))

    def custom(self, variables, class_name, method_name):
        """
        Additional custom fields to exist custom format
        """
        append = variables if variables else {}

        return {
            **append,
            **{
                'where_call': class_name,
                'method_caller': method_name,
                'link': self.__link,
                'instance': self.__instance_name
            }}

    #
    #   Setters/getters ----------------------------------------------------------------------------
    #

    @property
    def link(self) -> str:
        return self.__link

    @link.setter
    def link(self, value: str):
        self.__link = value

    @property
    def min_level_info(self) -> list:
        return self.__min_info

    @min_level_info.setter
    def min_level_info(self, value: str):
        self.__min_info.append(value)

    @property
    def min_level_warning(self) -> list:
        return self.__min_warning

    @min_level_warning.setter
    def min_level_warning(self, value: str):
        self.__min_warning.append(value)

==> endemic-0.1.1.tar.gz: endemic-0.1.1/src/endemic/logging/fluentd/logger.py <==
import logging
from fluent import handler
from ..interface import LoggerInterface

custom_format = {
    'host': '%(hostname)s',
    'type': '%(levelname)s',
    'stack_trace': '%(exc_text)s',
    'time': '%(created)s',
    'stack_info': '%(stack_info)s',
}


class LoggerFluentd(LoggerInterface):

    # threads - number of pool threads
    def __init__(
            self,
            instance: str,
            log_name: str,
            logger_tag: str = 'fluentd',
            level: str = LoggerInterface.DEBUG,
            host: str = '',
            port: int = 0
    ):
        super().__init__()
        self.__log = logging

        self.__instance_name = instance

        self.__fluentd_host = host
        self.__fluentd_port = port

        self.__logging_level = level
        self.__logging_logger = logger_tag
        self.__logging_name = log_name

        self.__min_info = []
        self.__min_warning = []

        self.__link = ''
        self.__where_call = None
        self.__who_call = None

        self.__setting()

    def __setting(self):
        """
        Setting logger and console output
        """
        logging.basicConfig(level=self.__logging_level,
                            format='%(asctime)s %(levelname)-8s %(message)s',
                            datefmt='%d/%m %H:%M')

        if self.__min_info:
            for i in self.__min_info:
                logging.getLogger(i).setLevel(logging.INFO)

        if self.__min_warning:
            for i in self.__min_warning:
                logging.getLogger(i).setLevel(logging.WARNING)

        if self.__fluentd_port and self.__fluentd_host:
            h = handler.FluentHandler(self.__logging_name, host=self.__fluentd_host, port=self.__fluentd_port)
        else:
            h = handler.FluentHandler(self.__logging_name)

        formatter = handler.FluentRecordFormatter(custom_format)
        h.setFormatter(formatter)

        self.__log = logging.getLogger(self.__logging_logger)

        if self.__fluentd_port and self.__fluentd_host:
            self.__log.addHandler(h)

    def debug(self, message, tag=None, class_name: str = None, variables: dict = None, method_name: str = None,
              exc_info=None):
        self.__log.debug({**{self.MESSAGE: message, self.TAG: tag}, **self.custom(variables, class_name, method_name)})

    def info(self, message, tag=None, class_name: str = None, variables: dict = None, method_name: str = None,
             exc_info=None):
        self.__log.info({**{self.MESSAGE: message, self.TAG: tag}, **self.custom(variables, class_name, method_name)})

    def warning(self, message, tag=None, class_name: str = None, variables: dict = None, method_name: str = None,
                exc_info=None):
        self.__log.warning(
            {**{self.MESSAGE: message, self.TAG: tag}, **self.custom(variables, class_name, method_name)})

    def error(self, message, tag=None, class_name: str = None, variables: dict = None, method_name: str = None,
              exc_info=None):
        self.__log.error({**{self.MESSAGE: message, self.TAG: tag}, **self.custom(variables, class_name, method_name)})

    def exception(self, message=None, tag=None, class_name: str = None, variables: dict = None,
                  method_name: str = None, exc_info=None):
        self.__log.exception(
            {**{self.MESSAGE: 'Exception', self.TAG: tag}, **self.custom(variables, class_name, method_name)})

    def critical(self, message, tag=None, class_name: str = None, variables: dict = None, method_name: str = None,
                 exc_info=None):
        self.__log.critical({**{self.MESSAGE: message, self.TAG: tag}, **self.custom(variables, class_name, method_name)})

    def custom(self, variables, class_name, method_name):
        """
        Additional custom fields to exist custom format
        """
        append = variables if variables else {}

        return {
            **append,
            **{
                'where_call': class_name,
                'method_caller': method_name,
                'link': self.__link,
                'instance': self.__instance_name
            }}

    #
    #   Setters/getters ----------------------------------------------------------------------------
    #

    @property
    def link(self) -> str:
        return self.__link

    @link.setter
    def link(self, value: str):
        self.__link = value

    @property
    def min_level_info(self) -> list:
        return self.__min_info

    @min_level_info.setter
    def min_level_info(self, value: str):
        self.__min_info.append(value)

    @property
    def min_level_warning(self) -> list:
        return self.__min_warning

    @min_level_warning.setter
    def min_level_warning(self, value: str):
        self.__min_warning.append(value)
